@@ -106,6 +106,7 @@ TEST_DECLARE   (spawn_and_kill_with_std)
 TEST_DECLARE   (spawn_and_ping)
 TEST_DECLARE   (kill)
 TEST_DECLARE   (fs_file_noent)
+TEST_DECLARE   (fs_file_nametoolong)
 TEST_DECLARE   (fs_file_async)
 TEST_DECLARE   (fs_file_sync)
 TEST_DECLARE   (fs_async_dir)
@@ -143,6 +144,7 @@ TEST_DECLARE   (argument_escaping)
 TEST_DECLARE   (environment_creation)
 TEST_DECLARE   (listen_with_simultaneous_accepts)
 TEST_DECLARE   (listen_no_simultaneous_accepts)
+TEST_DECLARE   (fs_stat_root)
 #endif
 HELPER_DECLARE (tcp4_echo_server)
 HELPER_DECLARE (tcp6_echo_server)
@@ -281,9 +283,11 @@ TASK_LIST_START
   TEST_ENTRY  (environment_creation)
   TEST_ENTRY  (listen_with_simultaneous_accepts)
   TEST_ENTRY  (listen_no_simultaneous_accepts)
+  TEST_ENTRY  (fs_stat_root)
 #endif
 
   TEST_ENTRY  (fs_file_noent)
+  TEST_ENTRY  (fs_file_nametoolong)
   TEST_ENTRY  (fs_file_async)
   TEST_ENTRY  (fs_file_sync)
   TEST_ENTRY  (fs_async_dir)
