@@ -50,7 +50,7 @@ class libuv_build_ext(build_ext):
     libuv_dir      = os.path.join('deps', 'libuv')
     libuv_repo     = 'https://github.com/joyent/libuv.git'
     libuv_branch   = 'master'
-    libuv_revision = '454e021'
+    libuv_revision = '3de0411'
     libuv_patches  = []
 
     user_options = build_ext.user_options
@@ -92,7 +92,7 @@ class libuv_build_ext(build_ext):
         def download_libuv():
             log.info('Downloading libuv...')
             makedirs(self.libuv_dir)
-            exec_process(['git', 'clone', '-b', self.libuv_branch, self.libuv_repo, self.libuv_dir])
+            exec_process(['git', 'clone', '--depth', '1', '-b', self.libuv_branch, self.libuv_repo, self.libuv_dir])
             exec_process(['git', 'checkout', self.libuv_revision], cwd=self.libuv_dir)
         def patch_libuv():
             log.info('Patching libuv...')
