@@ -6,9 +6,17 @@
 #include "Python.h"
 #include "structmember.h"
 
-/* system */
-#include <arpa/inet.h>
-#include <sys/socket.h>
+/* Python3 */
+#if PY_MAJOR_VERSION >= 3
+    #define PYUV_PYTHON3
+    #define PyInt_FromSsize_t PyLong_FromSsize_t
+    #define PyInt_FromLong PyLong_FromLong
+    #define PyString_FromString PyBytes_FromString
+    #define PyString_AsString PyBytes_AsString
+    #define PyString_FromStringAndSize PyBytes_FromStringAndSize
+    #define PyString_Check PyBytes_Check
+    #define PyString_Size PyBytes_Size
+#endif
 
 /* libuv */
 #include "uv.h"
@@ -22,7 +30,7 @@ typedef int Bool;
 
 /* Utility macros */
 #ifndef __STRING
-#define __STRING(x) #x
+    #define __STRING(x) #x
 #endif
 #define __MSTR(x) __STRING(x)
 
@@ -39,8 +47,13 @@ typedef int Bool;
 
 #define UV_LOOP(x) x->loop->uv_loop
 
+#if defined(__MINGW32__) || defined(_MSC_VER)
+    #define PYUV_WINDOWS
+#endif
+
 
 /* Python types definitions */
+
 /* Loop */
 typedef struct {
     PyObject_HEAD
