@@ -19,6 +19,7 @@ on_iostream_alloc(uv_stream_t* handle, size_t suggested_size)
 {
     PyGILState_STATE gstate = PyGILState_Ensure();
     uv_buf_t buf = uv_buf_init(PyMem_Malloc(suggested_size), suggested_size);
+    UNUSED_ARG(handle);
     PyGILState_Release(gstate);
     return buf;
 }
@@ -28,13 +29,13 @@ static void
 on_iostream_close(uv_handle_t *handle)
 {
     PyGILState_STATE gstate = PyGILState_Ensure();
+    IOStream *self;
+    PyObject *result;
     ASSERT(handle);
 
-    IOStream *self = (IOStream *)handle->data;
+    self = (IOStream *)handle->data;
     ASSERT(self);
 
-    PyObject *result;
-
     if (self->on_close_cb != Py_None) {
         result = PyObject_CallFunctionObjArgs(self->on_close_cb, self, NULL);
         if (result == NULL) {
@@ -71,21 +72,22 @@ static void
 on_iostream_shutdown(uv_shutdown_t* req, int status)
 {
     PyGILState_STATE gstate = PyGILState_Ensure();
+    iostream_req_data_t* req_data;
+    uv_err_t err;
+    IOStream *self;
+    PyObject *callback, *result, *py_errorno;
 
-    iostream_req_data_t* req_data = (iostream_req_data_t *)req->data;
-
-    IOStream *self = (IOStream *)req_data->obj;
-    PyObject *callback = req_data->callback;
+    req_data = (iostream_req_data_t *)req->data;
+    self = (IOStream *)req_data->obj;
+    callback = req_data->callback;
 
     ASSERT(self);
     /* Object could go out of scope in the callback, increase refcount to avoid it */
     Py_INCREF(self);
 
-    PyObject *result, *py_errorno;
-
     if (callback != Py_None) {
         if (status < 0) {
-            uv_err_t err = uv_last_error(UV_LOOP(self));
+            err = uv_last_error(UV_LOOP(self));
             py_errorno = PyInt_FromLong((long)err.code);
         } else {
             py_errorno = Py_None;
@@ -100,7 +102,6 @@ on_iostream_shutdown(uv_shutdown_t* req, int status)
 
     Py_DECREF(callback);
     PyMem_Free(req_data);
-    req->data = NULL;
     PyMem_Free(req);
 
     Py_DECREF(self);
@@ -112,15 +113,16 @@ static void
 on_iostream_read(uv_stream_t* handle, int nread, uv_buf_t buf)
 {
     PyGILState_STATE gstate = PyGILState_Ensure();
+    uv_err_t err;
+    IOStream *self;
+    PyObject *result, *data, *py_errorno;
     ASSERT(handle);
 
-    IOStream *self = (IOStream *)handle->data;
+    self = (IOStream *)handle->data;
     ASSERT(self);
     /* Object could go out of scope in the callback, increase refcount to avoid it */
     Py_INCREF(self);
 
-    PyObject *result, *data, *py_errorno;
-
     if (nread >= 0) {
         data = PyString_FromStringAndSize(buf.base, nread);
         py_errorno = Py_None;
@@ -128,7 +130,7 @@ on_iostream_read(uv_stream_t* handle, int nread, uv_buf_t buf)
     } else if (nread < 0) {
         data = Py_None;
         Py_INCREF(Py_None);
-        uv_err_t err = uv_last_error(UV_LOOP(self));
+        err = uv_last_error(UV_LOOP(self));
         py_errorno = PyInt_FromLong((long)err.code);
     }
 
@@ -148,26 +150,28 @@ on_iostream_read(uv_stream_t* handle, int nread, uv_buf_t buf)
 static void
 on_iostream_write(uv_write_t* req, int status)
 {
-    int i;
-
     PyGILState_STATE gstate = PyGILState_Ensure();
+    int i;
+    iostream_req_data_t* req_data;
+    iostream_write_data_t* write_data;
+    IOStream *self;
+    PyObject *callback, *result, *py_errorno;
+    uv_err_t err;
+
     ASSERT(req);
 
-    iostream_req_data_t* req_data = (iostream_req_data_t *)req->data;
-    iostream_write_data_t* write_data = (iostream_write_data_t *)req_data->data;
-
-    IOStream *self = (IOStream *)req_data->obj;
-    PyObject *callback = req_data->callback;
+    req_data = (iostream_req_data_t *)req->data;
+    write_data = (iostream_write_data_t *)req_data->data;
+    self = (IOStream *)req_data->obj;
+    callback = req_data->callback;
 
     ASSERT(self);
     /* Object could go out of scope in the callback, increase refcount to avoid it */
     Py_INCREF(self);
 
-    PyObject *result, *py_errorno;
-
     if (callback != Py_None) {
         if (status < 0) {
-            uv_err_t err = uv_last_error(UV_LOOP(self));
+            err = uv_last_error(UV_LOOP(self));
             py_errorno = PyInt_FromLong((long)err.code);
         } else {
             py_errorno = Py_None;
@@ -187,7 +191,6 @@ on_iostream_write(uv_write_t* req, int status)
     PyMem_Free(write_data);
     Py_DECREF(callback);
     PyMem_Free(req_data);
-    req->data = NULL;
     PyMem_Free(req);
 
     Py_DECREF(self);
@@ -230,10 +233,10 @@ IOStream_func_close(IOStream *self, PyObject *args)
 static PyObject *
 IOStream_func_shutdown(IOStream *self, PyObject *args)
 {
-    int r = 0;
-    PyObject *callback = Py_None;
+    int r;
     uv_shutdown_t *req = NULL;
     iostream_req_data_t *req_data = NULL;
+    PyObject *callback = Py_None;
 
     if (!self->uv_handle) {
         PyErr_SetString(PyExc_IOStreamError, "IOStream is already closed");
@@ -272,12 +275,9 @@ IOStream_func_shutdown(IOStream *self, PyObject *args)
 error:
     if (req_data) {
         Py_DECREF(callback);
-        req_data->obj = NULL;
-        req_data->callback = NULL;
         PyMem_Free(req_data);
     }
     if (req) {
-        req->data = NULL;
         PyMem_Free(req);
     }
     return NULL;
@@ -285,11 +285,12 @@ error:
 
 
 static PyObject *
-IOStream_func_start_read(IOStream *self, PyObject *args, PyObject *kwargs)
+IOStream_func_start_read(IOStream *self, PyObject *args)
 {
-    int r = 0;
-    PyObject *tmp = NULL;
-    PyObject *callback;
+    int r;
+    PyObject *tmp, *callback;
+
+    tmp = NULL;
 
     if (!self->uv_handle) {
         PyErr_SetString(PyExc_IOStreamError, "IOStream is closed");
@@ -321,14 +322,16 @@ IOStream_func_start_read(IOStream *self, PyObject *args, PyObject *kwargs)
 
 
 static PyObject *
-IOStream_func_stop_read(IOStream *self, PyObject *args, PyObject *kwargs)
+IOStream_func_stop_read(IOStream *self)
 {
+    int r;
+
     if (!self->uv_handle) {
         PyErr_SetString(PyExc_IOStreamError, "IOStream is closed");
         return NULL;
     }
 
-    int r = uv_read_stop(self->uv_handle);
+    r = uv_read_stop(self->uv_handle);
     if (r != 0) {
         raise_uv_exception(self->loop, PyExc_IOStreamError);
         return NULL;
@@ -341,21 +344,19 @@ IOStream_func_stop_read(IOStream *self, PyObject *args, PyObject *kwargs)
 static PyObject *
 IOStream_func_write(IOStream *self, PyObject *args)
 {
-    int i, n;
-    int r = 0;
-    int buf_count = 0;
-    char *data_str;
-    char *tmp;
+    int i, n, r, buf_count;
+    char *data_str, *tmp;
     Py_ssize_t data_len;
-    PyObject *item;
-    PyObject *data;
-    PyObject *callback = Py_None;
+    PyObject *item, *data, *callback;
     uv_buf_t tmpbuf;
     uv_buf_t *bufs = NULL;
     uv_write_t *wr = NULL;
     iostream_req_data_t *req_data = NULL;
     iostream_write_data_t *write_data = NULL;
 
+    buf_count = 0;
+    callback = Py_None;
+
     if (!self->uv_handle) {
         PyErr_SetString(PyExc_IOStreamError, "IOStream is closed");
         return NULL;
@@ -399,7 +400,7 @@ IOStream_func_write(IOStream *self, PyObject *args)
     wr->data = (void *)req_data;
 
     if (PyString_Check(data)) {
-        // We have a single string
+        /* We have a single string */
         bufs = (uv_buf_t *) PyMem_Malloc(sizeof(uv_buf_t));
         if (!bufs) {
             PyErr_NoMemory();
@@ -418,7 +419,7 @@ IOStream_func_write(IOStream *self, PyObject *args)
         bufs[0] = tmpbuf;
         buf_count = 1;
     } else {
-        // We have a list
+        /* We have a list */
         buf_count = 0;
         n = PySequence_Length(data);
         bufs = (uv_buf_t *) PyMem_Malloc(sizeof(uv_buf_t) * n);
@@ -467,13 +468,9 @@ error:
     }
     if (req_data) {
         Py_DECREF(callback);
-        req_data->obj = NULL;
-        req_data->callback = NULL;
-        req_data->data = NULL;
         PyMem_Free(req_data);
     }
     if (wr) {
-        wr->data = NULL;
         PyMem_Free(wr);
     }
     return NULL;
