@@ -6,16 +6,18 @@ static void
 on_tcp_connection(uv_stream_t* server, int status)
 {
     PyGILState_STATE gstate = PyGILState_Ensure();
+    TCP *self;
+    IOStream *base;
+    PyObject *result, *py_errorno;
+
     ASSERT(server);
+    self = (TCP *)server->data;
 
-    TCP *self = (TCP *)server->data;
     ASSERT(self);
     /* Object could go out of scope in the callback, increase refcount to avoid it */
     Py_INCREF(self);
 
-    IOStream *base = (IOStream *)self;
-
-    PyObject *result, *py_errorno;
+    base = (IOStream *)self;
 
     if (status != 0) {
         uv_err_t err = uv_last_error(UV_LOOP(base));
@@ -40,20 +42,22 @@ static void
 on_tcp_client_connection(uv_connect_t *req, int status)
 {
     PyGILState_STATE gstate = PyGILState_Ensure();
+    iostream_req_data_t* req_data;
+    TCP *self;
+    IOStream *base;
+    PyObject *callback, *result, *py_errorno;
+
     ASSERT(req);
+    req_data = (iostream_req_data_t *)req->data;
 
-    iostream_req_data_t* req_data = (iostream_req_data_t *)req->data;
-
-    TCP *self = (TCP *)req_data->obj;
-    PyObject *callback = req_data->callback;
-
-    PyObject *result, *py_errorno;
+    self = (TCP *)req_data->obj;
+    callback = req_data->callback;
 
     ASSERT(self);
     /* Object could go out of scope in the callback, increase refcount to avoid it */
     Py_INCREF(self);
 
-    IOStream *base = (IOStream *)self;
+    base = (IOStream *)self;
 
     if (status != 0) {
         uv_err_t err = uv_last_error(UV_LOOP(base));
@@ -71,7 +75,6 @@ on_tcp_client_connection(uv_connect_t *req, int status)
 
     Py_DECREF(callback);
     PyMem_Free(req_data);
-    req->data = NULL;
     PyMem_Free(req);
 
     Py_DECREF(self);
@@ -82,10 +85,8 @@ on_tcp_client_connection(uv_connect_t *req, int status)
 static PyObject *
 TCP_func_bind(TCP *self, PyObject *args)
 {
-    int r = 0;
+    int r, bind_port, address_type;
     char *bind_ip;
-    int bind_port;
-    int address_type;
     struct in_addr addr4;
     struct in6_addr addr6;
 
@@ -105,9 +106,9 @@ TCP_func_bind(TCP *self, PyObject *args)
         return NULL;
     }
 
-    if (inet_pton(AF_INET, bind_ip, &addr4) == 1) {
+    if (uv_inet_pton(AF_INET, bind_ip, &addr4) == 1) {
         address_type = AF_INET;
-    } else if (inet_pton(AF_INET6, bind_ip, &addr6) == 1) {
+    } else if (uv_inet_pton(AF_INET6, bind_ip, &addr6) == 1) {
         address_type = AF_INET6;
     } else {
         PyErr_SetString(PyExc_ValueError, "invalid IP address");
@@ -132,13 +133,14 @@ TCP_func_bind(TCP *self, PyObject *args)
 static PyObject *
 TCP_func_listen(TCP *self, PyObject *args)
 {
-    int r;
-    int backlog = 128;
-    PyObject *callback;
-    PyObject *tmp = NULL;
+    int r, backlog;
+    PyObject *callback, *tmp;
 
     IOStream *base = (IOStream *)self;
 
+    backlog = 128;
+    tmp = NULL;
+
     if (!base->uv_handle) {
         PyErr_SetString(PyExc_TCPError, "already closed");
         return NULL;
@@ -176,7 +178,7 @@ TCP_func_listen(TCP *self, PyObject *args)
 static PyObject *
 TCP_func_accept(TCP *self, PyObject *args)
 {
-    int r = 0;
+    int r;
     PyObject *client;
 
     IOStream *base = (IOStream *)self;
@@ -206,18 +208,15 @@ TCP_func_accept(TCP *self, PyObject *args)
 
 
 static PyObject *
-TCP_func_connect(TCP *self, PyObject *args, PyObject *kwargs)
+TCP_func_connect(TCP *self, PyObject *args)
 {
-    int r;
+    int r, connect_port, address_type;
     char *connect_ip;
-    int connect_port;
-    int address_type;
     struct in_addr addr4;
     struct in6_addr addr6;
     uv_connect_t *connect_req = NULL;
     iostream_req_data_t *req_data = NULL;
-    PyObject *connect_address;
-    PyObject *callback;
+    PyObject *connect_address, *callback;
 
     IOStream *base = (IOStream *)self;
 
@@ -244,9 +243,9 @@ TCP_func_connect(TCP *self, PyObject *args, PyObject *kwargs)
         return NULL;
     }
 
-    if (inet_pton(AF_INET, connect_ip, &addr4) == 1) {
+    if (uv_inet_pton(AF_INET, connect_ip, &addr4) == 1) {
         address_type = AF_INET;
-    } else if (inet_pton(AF_INET6, connect_ip, &addr6) == 1) {
+    } else if (uv_inet_pton(AF_INET6, connect_ip, &addr6) == 1) {
         address_type = AF_INET6;
     } else {
         PyErr_SetString(PyExc_ValueError, "invalid IP address");
@@ -285,13 +284,10 @@ TCP_func_connect(TCP *self, PyObject *args, PyObject *kwargs)
 
 error:
     if (connect_req) {
-        connect_req->data = NULL;
         PyMem_Free(connect_req);
     }
     if (req_data) {
         Py_DECREF(callback);
-        req_data->obj = NULL;
-        req_data->callback = NULL;
         PyMem_Free(req_data);
     }
     return NULL;
@@ -301,21 +297,22 @@ error:
 static PyObject *
 TCP_func_getsockname(TCP *self)
 {
+    int r, namelen;
+    char ip[INET6_ADDRSTRLEN];
     struct sockaddr sockname;
     struct sockaddr_in *addr4;
     struct sockaddr_in6 *addr6;
-    char ip4[INET_ADDRSTRLEN];
-    char ip6[INET6_ADDRSTRLEN];
-    int namelen = sizeof(sockname);
 
     IOStream *base = (IOStream *)self;
 
+    namelen = sizeof(sockname);
+
     if (!base->uv_handle) {
         PyErr_SetString(PyExc_TCPError, "closed");
         return NULL;
     }
 
-    int r = uv_tcp_getsockname((uv_tcp_t *)base->uv_handle, &sockname, &namelen);
+    r = uv_tcp_getsockname((uv_tcp_t *)base->uv_handle, &sockname, &namelen);
     if (r != 0) {
         raise_uv_exception(base->loop, PyExc_TCPError);
         return NULL;
@@ -323,14 +320,12 @@ TCP_func_getsockname(TCP *self)
 
     if (sockname.sa_family == AF_INET) {
         addr4 = (struct sockaddr_in*)&sockname;
-        r = uv_ip4_name(addr4, ip4, INET_ADDRSTRLEN);
-        ASSERT(r == 0);
-        return Py_BuildValue("si", ip4, ntohs(addr4->sin_port));
+        uv_ip4_name(addr4, ip, INET_ADDRSTRLEN);
+        return Py_BuildValue("si", ip, ntohs(addr4->sin_port));
     } else if (sockname.sa_family == AF_INET6) {
         addr6 = (struct sockaddr_in6*)&sockname;
-        r = uv_ip6_name(addr6, ip6, INET6_ADDRSTRLEN);
-        ASSERT(r == 0);
-        return Py_BuildValue("si", ip6, ntohs(addr6->sin6_port));
+        uv_ip6_name(addr6, ip, INET6_ADDRSTRLEN);
+        return Py_BuildValue("si", ip, ntohs(addr6->sin6_port));
     } else {
         PyErr_SetString(PyExc_TCPError, "unknown address type detected");
         return NULL;
@@ -341,21 +336,22 @@ TCP_func_getsockname(TCP *self)
 static PyObject *
 TCP_func_getpeername(TCP *self)
 {
+    int r, namelen;
+    char ip[INET6_ADDRSTRLEN];
     struct sockaddr peername;
     struct sockaddr_in *addr4;
     struct sockaddr_in6 *addr6;
-    char ip4[INET_ADDRSTRLEN];
-    char ip6[INET6_ADDRSTRLEN];
-    int namelen = sizeof(peername);
 
     IOStream *base = (IOStream *)self;
 
+    namelen = sizeof(peername);
+
     if (!base->uv_handle) {
         PyErr_SetString(PyExc_TCPError, "closed");
         return NULL;
     }
 
-    int r = uv_tcp_getpeername((uv_tcp_t *)base->uv_handle, &peername, &namelen);
+    r = uv_tcp_getpeername((uv_tcp_t *)base->uv_handle, &peername, &namelen);
     if (r != 0) {
         raise_uv_exception(base->loop, PyExc_TCPError);
         return NULL;
@@ -363,14 +359,14 @@ TCP_func_getpeername(TCP *self)
 
     if (peername.sa_family == AF_INET) {
         addr4 = (struct sockaddr_in*)&peername;
-        r = uv_ip4_name(addr4, ip4, INET_ADDRSTRLEN);
+        r = uv_ip4_name(addr4, ip, INET_ADDRSTRLEN);
         ASSERT(r == 0);
-        return Py_BuildValue("si", ip4, ntohs(addr4->sin_port));
+        return Py_BuildValue("si", ip, ntohs(addr4->sin_port));
     } else if (peername.sa_family == AF_INET6) {
         addr6 = (struct sockaddr_in6*)&peername;
-        r = uv_ip6_name(addr6, ip6, INET6_ADDRSTRLEN);
+        r = uv_ip6_name(addr6, ip, INET6_ADDRSTRLEN);
         ASSERT(r == 0);
-        return Py_BuildValue("si", ip6, ntohs(addr6->sin6_port));
+        return Py_BuildValue("si", ip, ntohs(addr6->sin6_port));
     } else {
         PyErr_SetString(PyExc_TCPError, "unknown address type detected");
         return NULL;
@@ -381,7 +377,7 @@ TCP_func_getpeername(TCP *self)
 static PyObject *
 TCP_func_nodelay(TCP *self, PyObject *args)
 {
-    int r = 0;
+    int r;
     PyObject *enable;
 
     IOStream *base = (IOStream *)self;
@@ -408,7 +404,7 @@ TCP_func_nodelay(TCP *self, PyObject *args)
 static PyObject *
 TCP_func_keepalive(TCP *self, PyObject *args)
 {
-    int r = 0;
+    int r;
     unsigned int delay;
     PyObject *enable;
 
@@ -445,7 +441,7 @@ TCP_func_simultaneous_accepts(TCP *self, PyObject *args)
     * accepting connections (which is why it is enabled by default).
     */
 
-    int r = 0;
+    int r;
     PyObject *enable;
 
     IOStream *base = (IOStream *)self;
@@ -472,13 +468,15 @@ TCP_func_simultaneous_accepts(TCP *self, PyObject *args)
 static int
 TCP_tp_init(TCP *self, PyObject *args, PyObject *kwargs)
 {
-    int r = 0;
+    int r;
+    uv_tcp_t *uv_stream;
     Loop *loop;
     PyObject *tmp = NULL;
-    uv_tcp_t *uv_stream;
 
     IOStream *base = (IOStream *)self;
 
+    UNUSED_ARG(kwargs);
+
     if (base->uv_handle) {
         PyErr_SetString(PyExc_TCPError, "Object already initialized");
         return -1;
