@@ -26,7 +26,7 @@ class FSTestStat(unittest2.TestCase):
     def tearDown(self):
         os.remove(TEST_FILE)
 
-    def stat_cb(self, loop, data, path, stat_result, errorno):
+    def stat_cb(self, loop, path, stat_result, errorno):
         self.errorno = errorno
 
     def test_stat_error(self):
@@ -41,6 +41,31 @@ class FSTestStat(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.errorno, None)
 
+    def test_stat_sync(self):
+        self.stat_data = None
+        def timer_cb(handle):
+            self.stat_data = pyuv.fs.stat(self.loop, TEST_FILE)
+            handle.close()
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertNotEqual(self.stat_data, None)
+
+    def test_stat_error_sync(self):
+        self.errorno = None
+        def timer_cb(handle):
+            handle.close()
+            try:
+                pyuv.fs.stat(self.loop, BAD_FILE)
+            except pyuv.error.FSError as e:
+                self.errorno = e.args[0]
+            else:
+                self.fail("Should have raised FSError")
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.errorno, pyuv.errno.UV_ENOENT)
+
 
 @platform_skip(["win32"])
 class FSTestLstat(unittest2.TestCase):
@@ -55,15 +80,9 @@ class FSTestLstat(unittest2.TestCase):
         os.remove(TEST_FILE)
         os.remove(TEST_LINK)
 
-    def stat_cb(self, loop, data, path, stat_result, errorno):
+    def stat_cb(self, loop, path, stat_result, errorno):
         self.errorno = errorno
 
-    def test_stat(self):
-        self.errorno = None
-        pyuv.fs.stat(self.loop, TEST_FILE, self.stat_cb)
-        self.loop.run()
-        self.assertEqual(self.errorno, None)
-
     def test_lstat(self):
         self.errorno = None
         pyuv.fs.lstat(self.loop, TEST_LINK, self.stat_cb)
@@ -82,7 +101,7 @@ class FSTestFstat(unittest2.TestCase):
         self.file.close()
         os.remove(TEST_FILE)
 
-    def fstat_cb(self, loop, data, path, stat_data, errorno):
+    def fstat_cb(self, loop, path, stat_data, errorno):
         self.errorno = errorno
 
     def test_fstat(self):
@@ -91,6 +110,16 @@ class FSTestFstat(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.errorno, None)
 
+    def test_fstat_sync(self):
+        self.stat_data = None
+        def timer_cb(handle):
+            self.stat_data = pyuv.fs.fstat(self.loop, self.file.fileno())
+            handle.close()
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertNotEqual(self.stat_data, None)
+
 
 class FSTestUnlink(unittest2.TestCase):
 
@@ -105,7 +134,7 @@ class FSTestUnlink(unittest2.TestCase):
         except OSError:
             pass
 
-    def bad_unlink_cb(self, loop, data, path, errorno):
+    def bad_unlink_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_bad_unlink(self):
@@ -114,7 +143,7 @@ class FSTestUnlink(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.errorno, pyuv.errno.UV_ENOENT)
 
-    def unlink_cb(self, loop, data, path, errorno):
+    def unlink_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_unlink(self):
@@ -123,6 +152,29 @@ class FSTestUnlink(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.errorno, None)
 
+    def test_unlink_sync(self):
+        def timer_cb(handle):
+            pyuv.fs.unlink(self.loop, TEST_FILE)
+            handle.close()
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+
+    def test_unlink_error_sync(self):
+        self.errorno = None
+        def timer_cb(handle):
+            handle.close()
+            try:
+                pyuv.fs.unlink(self.loop, BAD_FILE)
+            except pyuv.error.FSError as e:
+                self.errorno = e.args[0]
+            else:
+                self.fail("Should have raised FSError")
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.errorno, pyuv.errno.UV_ENOENT)
+
 
 class FSTestMkdir(unittest2.TestCase):
 
@@ -137,7 +189,7 @@ class FSTestMkdir(unittest2.TestCase):
         except OSError:
             pass
 
-    def mkdir_cb(self, loop, data, path, errorno):
+    def mkdir_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_bad_mkdir(self):
@@ -153,6 +205,30 @@ class FSTestMkdir(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertTrue(os.path.isdir(TEST_DIR))
 
+    def test_mkdir_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.mkdir(self.loop, TEST_DIR, 0o755)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertTrue(os.path.isdir(TEST_DIR))
+
+    def test_mkdir_error_sync(self):
+        self.errorno = None
+        def timer_cb(handle):
+            handle.close()
+            try:
+                pyuv.fs.mkdir(self.loop, BAD_DIR, 0o755)
+            except pyuv.error.FSError as e:
+                self.errorno = e.args[0]
+            else:
+                self.fail("Should have raised FSError")
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.errorno, pyuv.errno.UV_EEXIST)
+
 
 class FSTestRmdir(unittest2.TestCase):
 
@@ -166,7 +242,7 @@ class FSTestRmdir(unittest2.TestCase):
         except OSError:
             pass
 
-    def rmdir_cb(self, loop, data, path, errorno):
+    def rmdir_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_bad_rmdir(self):
@@ -182,6 +258,30 @@ class FSTestRmdir(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertFalse(os.path.isdir(TEST_DIR))
 
+    def test_rmdir_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.rmdir(self.loop, TEST_DIR)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertFalse(os.path.isdir(TEST_DIR))
+
+    def test_rmdir_error_sync(self):
+        self.errorno = None
+        def timer_cb(handle):
+            handle.close()
+            try:
+                pyuv.fs.rmdir(self.loop, BAD_DIR)
+            except pyuv.error.FSError as e:
+                self.errorno = e.args[0]
+            else:
+                self.fail("Should have raised FSError")
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.errorno, pyuv.errno.UV_ENOENT)
+
 
 class FSTestRename(unittest2.TestCase):
 
@@ -200,7 +300,7 @@ class FSTestRename(unittest2.TestCase):
         except OSError:
             pass
 
-    def rename_cb(self, loop, data, path, errorno):
+    def rename_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_rename(self):
@@ -211,6 +311,16 @@ class FSTestRename(unittest2.TestCase):
         self.assertFalse(os.path.exists(TEST_FILE))
         self.assertTrue(os.path.exists(TEST_FILE2))
 
+    def test_rename_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.rename(self.loop, TEST_FILE, TEST_FILE2)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertFalse(os.path.exists(TEST_FILE))
+        self.assertTrue(os.path.exists(TEST_FILE2))
+
 
 class FSTestChmod(unittest2.TestCase):
 
@@ -222,7 +332,7 @@ class FSTestChmod(unittest2.TestCase):
     def tearDown(self):
         os.remove(TEST_FILE)
 
-    def chmod_cb(self, loop, data, path, errorno):
+    def chmod_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_chmod(self):
@@ -233,6 +343,16 @@ class FSTestChmod(unittest2.TestCase):
         mode = os.stat(TEST_FILE).st_mode
         self.assertTrue(bool(mode & stat.S_IRWXU) and bool(mode & stat.S_IRWXG) and bool(mode & stat.S_IRWXO))
 
+    def test_chmod_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.chmod(self.loop, TEST_FILE, 0o777)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        mode = os.stat(TEST_FILE).st_mode
+        self.assertTrue(bool(mode & stat.S_IRWXU) and bool(mode & stat.S_IRWXG) and bool(mode & stat.S_IRWXO))
+
 
 @platform_skip(["win32"])
 class FSTestFchmod(unittest2.TestCase):
@@ -246,7 +366,7 @@ class FSTestFchmod(unittest2.TestCase):
         self.file.close()
         os.remove(TEST_FILE)
 
-    def fchmod_cb(self, loop, data, path, errorno):
+    def fchmod_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_fchmod(self):
@@ -257,6 +377,16 @@ class FSTestFchmod(unittest2.TestCase):
         mode = os.stat(TEST_FILE).st_mode
         self.assertTrue(bool(mode & stat.S_IRWXU) and bool(mode & stat.S_IRWXG) and bool(mode & stat.S_IRWXO))
 
+    def test_fchmod_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.fchmod(self.loop, self.file.fileno(), 0o777)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        mode = os.stat(TEST_FILE).st_mode
+        self.assertTrue(bool(mode & stat.S_IRWXU) and bool(mode & stat.S_IRWXG) and bool(mode & stat.S_IRWXO))
+
 
 class FSTestLink(unittest2.TestCase):
 
@@ -269,7 +399,7 @@ class FSTestLink(unittest2.TestCase):
         os.remove(TEST_FILE)
         os.remove(TEST_LINK)
 
-    def link_cb(self, loop, data, path, errorno):
+    def link_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_link(self):
@@ -279,6 +409,15 @@ class FSTestLink(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertEqual(os.stat(TEST_FILE).st_ino, os.stat(TEST_LINK).st_ino)
 
+    def test_link_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.link(self.loop, TEST_FILE, TEST_LINK)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(os.stat(TEST_FILE).st_ino, os.stat(TEST_LINK).st_ino)
+
 
 @platform_skip(["win32"])
 class FSTestSymlink(unittest2.TestCase):
@@ -295,7 +434,7 @@ class FSTestSymlink(unittest2.TestCase):
         except OSError:
             pass
 
-    def symlink_cb(self, loop, data, path, errorno):
+    def symlink_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_symlink(self):
@@ -305,6 +444,15 @@ class FSTestSymlink(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertTrue(os.path.islink(TEST_LINK))
 
+    def test_symlink_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.symlink(self.loop, TEST_FILE, TEST_LINK, 0)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertTrue(os.path.islink(TEST_LINK))
+
 
 @platform_skip(["win32"])
 class FSTestReadlink(unittest2.TestCase):
@@ -319,7 +467,7 @@ class FSTestReadlink(unittest2.TestCase):
         os.remove(TEST_FILE)
         os.remove(TEST_LINK)
 
-    def readlink_cb(self, loop, data, path, errorno):
+    def readlink_cb(self, loop, path, errorno):
         self.errorno = errorno
         self.link_path = path
 
@@ -331,6 +479,15 @@ class FSTestReadlink(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertEqual(self.link_path, TEST_FILE)
 
+    def test_readlink_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            self.link_path = pyuv.fs.readlink(self.loop, TEST_LINK)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.link_path, TEST_FILE)
+
 
 class FSTestChown(unittest2.TestCase):
 
@@ -342,7 +499,7 @@ class FSTestChown(unittest2.TestCase):
     def tearDown(self):
         os.remove(TEST_FILE)
 
-    def chown_cb(self, loop, data, path, errorno):
+    def chown_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_chown(self):
@@ -351,6 +508,14 @@ class FSTestChown(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.errorno, None)
 
+    def test_chown_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.chown(self.loop, TEST_FILE, -1, -1)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+
 
 class FSTestFchown(unittest2.TestCase):
 
@@ -363,7 +528,7 @@ class FSTestFchown(unittest2.TestCase):
         self.file.close()
         os.remove(TEST_FILE)
 
-    def fchown_cb(self, loop, data, path, errorno):
+    def fchown_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_fchown(self):
@@ -372,11 +537,23 @@ class FSTestFchown(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.errorno, None)
 
+    def test_fchown_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.fchown(self.loop, self.file.fileno(), -1, -1)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+
 
 class FSTestOpen(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
+        try:
+            os.remove(TEST_FILE)
+        except OSError:
+            pass
 
     def tearDown(self):
         try:
@@ -384,11 +561,11 @@ class FSTestOpen(unittest2.TestCase):
         except OSError:
             pass
 
-    def close_cb(self, loop, data, path, errorno):
+    def close_cb(self, loop, path, errorno):
         self.errorno = errorno
 
-    def open_cb(self, loop, data, path, fd, errorno):
-        self.assertNotEqual(fd, -1)
+    def open_cb(self, loop, path, fd, errorno):
+        self.assertNotEqual(fd, None)
         self.assertEqual(errorno, None)
         pyuv.fs.close(self.loop, fd, self.close_cb)
 
@@ -398,7 +575,7 @@ class FSTestOpen(unittest2.TestCase):
         self.loop.run()
         self.assertEqual(self.errorno, None)
 
-    def open_noent_cb(self, loop, data, path, fd, errorno):
+    def open_noent_cb(self, loop, path, fd, errorno):
         self.fd = fd
         self.errorno = errorno
 
@@ -407,7 +584,31 @@ class FSTestOpen(unittest2.TestCase):
         self.errorno = None
         pyuv.fs.open(self.loop, BAD_FILE, os.O_RDONLY, 0, self.open_noent_cb)
         self.loop.run()
-        self.assertEqual(self.fd, -1)
+        self.assertEqual(self.fd, None)
+        self.assertEqual(self.errorno, pyuv.errno.UV_ENOENT)
+
+    def test_open_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            fd = pyuv.fs.open(self.loop, TEST_FILE, os.O_WRONLY|os.O_CREAT|os.O_TRUNC, stat.S_IREAD|stat.S_IWRITE)
+            pyuv.fs.close(self.loop, fd)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+
+    def test_open_error_sync(self):
+        self.errorno = None
+        def timer_cb(handle):
+            handle.close()
+            try:
+                pyuv.fs.open(self.loop, BAD_FILE, os.O_RDONLY, 0)
+            except pyuv.error.FSError as e:
+                self.errorno = e.args[0]
+            else:
+                self.fail("Should have raised FSError")
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
         self.assertEqual(self.errorno, pyuv.errno.UV_ENOENT)
 
 
@@ -424,7 +625,7 @@ class FSTestRead(unittest2.TestCase):
         self.file.close()
         os.remove(TEST_FILE)
 
-    def read_cb(self, loop, data, path, read_data, errorno):
+    def read_cb(self, loop, path, read_data, errorno):
         self.errorno = errorno
         self.data = read_data
 
@@ -436,6 +637,16 @@ class FSTestRead(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertEqual(self.data, 'test')
 
+    def test_read_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            self.data = pyuv.fs.read(self.loop, self.file.fileno(), 4, -1)
+        self.data = None
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.data, 'test')
+
 
 @platform_skip(["win32"])
 class FSTestWrite(unittest2.TestCase):
@@ -447,7 +658,7 @@ class FSTestWrite(unittest2.TestCase):
     def tearDown(self):
         os.remove(TEST_FILE)
 
-    def write_cb(self, loop, data, path, bytes_written, errorno):
+    def write_cb(self, loop, path, bytes_written, errorno):
         self.file.close()
         self.bytes_written = bytes_written
         self.errorno = errorno
@@ -470,6 +681,17 @@ class FSTestWrite(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertEqual(open(TEST_FILE, 'r').read(), "TES\x00T")
 
+    def test_write_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            self.bytes_written = pyuv.fs.write(self.loop, self.file.fileno(), "TEST", -1)
+        self.bytes_written = None
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.bytes_written, 4)
+        self.assertEqual(open(TEST_FILE, 'r').read(), "TEST")
+
 
 @platform_skip(["win32"])
 class FSTestFsync(unittest2.TestCase):
@@ -481,16 +703,16 @@ class FSTestFsync(unittest2.TestCase):
     def tearDown(self):
         os.remove(TEST_FILE)
 
-    def write_cb(self, loop, data, path, bytes_written, errorno):
+    def write_cb(self, loop, path, bytes_written, errorno):
         self.assertEqual(bytes_written, 4)
         self.assertEqual(errorno, None)
         pyuv.fs.fdatasync(self.loop, self.file.fileno(), self.fdatasync_cb)
 
-    def fdatasync_cb(self, loop, data, path, errorno):
+    def fdatasync_cb(self, loop, path, errorno):
         self.assertEqual(errorno, None)
         pyuv.fs.fsync(self.loop, self.file.fileno(), self.fsync_cb)
 
-    def fsync_cb(self, loop, data, path, errorno):
+    def fsync_cb(self, loop, path, errorno):
         self.assertEqual(errorno, None)
 
     def test_fsync(self):
@@ -499,6 +721,18 @@ class FSTestFsync(unittest2.TestCase):
         self.file.close()
         self.assertEqual(open(TEST_FILE, 'r').read(), "TEST")
 
+    def test_fsync_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.write(self.loop, self.file.fileno(), "TEST", -1)
+            pyuv.fs.fdatasync(self.loop, self.file.fileno())
+            pyuv.fs.fsync(self.loop, self.file.fileno())
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.file.close()
+        self.assertEqual(open(TEST_FILE, 'r').read(), "TEST")
+
 
 @platform_skip(["win32"])
 class FSTestFtruncate(unittest2.TestCase):
@@ -513,7 +747,7 @@ class FSTestFtruncate(unittest2.TestCase):
         self.file.close()
         os.remove(TEST_FILE)
 
-    def ftruncate_cb(self, loop, data, path, errorno):
+    def ftruncate_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_ftruncate1(self):
@@ -530,6 +764,15 @@ class FSTestFtruncate(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertEqual(open(TEST_FILE, 'r').read(), "")
 
+    def test_ftruncate_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.ftruncate(self.loop, self.file.fileno(), 0)
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(open(TEST_FILE, 'r').read(), "")
+
 
 class FSTestReaddir(unittest2.TestCase):
 
@@ -545,7 +788,7 @@ class FSTestReaddir(unittest2.TestCase):
     def tearDown(self):
         shutil.rmtree(TEST_DIR)
 
-    def readdir_cb(self, loop, data, path, files, errorno):
+    def readdir_cb(self, loop, path, files, errorno):
         self.errorno = errorno
         self.files = files
 
@@ -566,6 +809,34 @@ class FSTestReaddir(unittest2.TestCase):
         self.assertTrue(TEST_FILE2 in self.files)
         self.assertTrue(TEST_DIR2 in self.files)
 
+    def test_readdir_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            self.files = pyuv.fs.readdir(self.loop, TEST_DIR, 0)
+        self.files = None
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertNotEqual(self.files, None)
+        self.assertTrue(TEST_FILE in self.files)
+        self.assertTrue(TEST_FILE2 in self.files)
+        self.assertTrue(TEST_DIR2 in self.files)
+
+    def test_readdir_error_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            try:
+                pyuv.fs.readdir(self.loop, BAD_DIR, 0)
+            except pyuv.error.FSError as e:
+                self.errorno = e.args[0]
+            else:
+                self.fail("Should have raised FSError")
+        self.errorno = None
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.errorno, pyuv.errno.UV_ENOENT)
+
 
 @platform_skip(["win32"])
 class FSTestSendfile(unittest2.TestCase):
@@ -586,7 +857,7 @@ class FSTestSendfile(unittest2.TestCase):
         os.remove(TEST_FILE)
         os.remove(TEST_FILE2)
 
-    def sendfile_cb(self, loop, data, path, bytes_written, errorno):
+    def sendfile_cb(self, loop, path, bytes_written, errorno):
         self.bytes_written = bytes_written
         self.errorno = errorno
 
@@ -599,6 +870,17 @@ class FSTestSendfile(unittest2.TestCase):
         self.assertEqual(self.errorno, None)
         self.assertEqual(open(TEST_FILE, 'r').read(), open(TEST_FILE2, 'r').read())
 
+    def test_sendfile_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            self.bytes_written = pyuv.fs.sendfile(self.loop, self.new_file.fileno(), self.file.fileno(), 0, 131072)
+        self.bytes_written = None
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        self.assertEqual(self.bytes_written, 65546)
+        self.assertEqual(open(TEST_FILE, 'r').read(), open(TEST_FILE2, 'r').read())
+
 
 @platform_skip(["win32"])
 class FSTestUtime(unittest2.TestCase):
@@ -613,7 +895,7 @@ class FSTestUtime(unittest2.TestCase):
         self.file.close()
         os.remove(TEST_FILE)
 
-    def utime_cb(self, loop, data, path, errorno):
+    def utime_cb(self, loop, path, errorno):
         self.errorno = errorno
 
     def test_utime(self):
@@ -635,6 +917,30 @@ class FSTestUtime(unittest2.TestCase):
         s = os.stat(TEST_FILE)
         self.assertTrue(s.st_atime == atime and s.st_mtime == mtime)
 
+    def test_utime_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.utime(self.loop, TEST_FILE, atime, mtime)
+        atime = mtime = 400497753
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        s = os.stat(TEST_FILE)
+        self.assertEqual(s.st_atime, atime)
+        self.assertEqual(s.st_mtime, mtime)
+
+    def test_futime_sync(self):
+        def timer_cb(handle):
+            handle.close()
+            pyuv.fs.futime(self.loop, self.file.fileno(), atime, mtime)
+        atime = mtime = 400497753
+        timer = pyuv.Timer(self.loop)
+        timer.start(timer_cb, 0.1, 0)
+        self.loop.run()
+        s = os.stat(TEST_FILE)
+        self.assertEqual(s.st_atime, atime)
+        self.assertEqual(s.st_mtime, mtime)
+
 
 @platform_skip(["linux", "darwin"])
 class FSEventTestBasic(unittest2.TestCase):
