@@ -1,11 +1,19 @@
 
-import common
+import sys
+
+from common import unittest2, platform_skip
 import pyuv
 
-
 TEST_PORT = 1234
 
-class IPCTest(common.UVTestCase):
+if sys.version_info > (3, 0):
+    EXECUTABLE = sys.executable.encode()
+else:
+    EXECUTABLE = sys.executable
+
+
+@platform_skip(["win32"])
+class IPCTest(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
@@ -18,7 +26,7 @@ class IPCTest(common.UVTestCase):
         self.connections.remove(client)
 
     def make_many_connections(self):
-        for i in xrange(100):
+        for i in range(100):
             conn = pyuv.TCP(self.loop)
             self.connections.append(conn)
             conn.connect(("127.0.0.1", TEST_PORT), self.on_client_connection)
@@ -38,11 +46,11 @@ class IPCTest(common.UVTestCase):
             self.tcp_server = pyuv.TCP(self.loop)
             self.channel.accept(self.tcp_server)
             self.tcp_server.listen(self.on_ipc_connection, 12)
-            self.assertEqual(data.strip(), "hello")
-            self.channel.write("world")
+            self.assertEqual(data.strip(), b"hello")
+            self.channel.write(b"world")
             self.make_many_connections()
         else:
-            if data.strip() == "accepted_connection":
+            if data.strip() == b"accepted_connection":
                 self.assertEqual(pending, pyuv.UV_UNKNOWN_HANDLE)
                 self.channel.close()
 
@@ -52,7 +60,10 @@ class IPCTest(common.UVTestCase):
         self.tcp_server = None
         self.channel = pyuv.Pipe(self.loop, True)
         proc = pyuv.Process(self.loop)
-        proc.spawn(file="./proc_ipc.py", args=["listen_before_write"], exit_callback=self.proc_exit_cb, stdin=self.channel)
+        if sys.platform == 'win32':
+            proc.spawn(file="cmd.exe", args=[b"/c", EXECUTABLE+ b" proc_ipc.py", b"listen_before_write"], exit_callback=self.proc_exit_cb, stdin=self.channel)
+        else:
+            proc.spawn(file=sys.executable , args=[b"proc_ipc.py", b"listen_before_write"], exit_callback=self.proc_exit_cb, stdin=self.channel)
         self.channel.start_read2(self.on_channel_read)
         self.loop.run()
 
@@ -62,13 +73,13 @@ class IPCTest(common.UVTestCase):
         self.tcp_server = None
         self.channel = pyuv.Pipe(self.loop, True)
         proc = pyuv.Process(self.loop)
-        proc.spawn(file="./proc_ipc.py", args=["listen_after_write"], exit_callback=self.proc_exit_cb, stdin=self.channel)
+        if sys.platform == 'win32':
+            proc.spawn(file="cmd.exe", args=[b"/c", EXECUTABLE+ b" proc_ipc.py", b"listen_after_write"], exit_callback=self.proc_exit_cb, stdin=self.channel)
+        else:
+            proc.spawn(file=sys.executable, args=[b"proc_ipc.py", b"listen_after_write"], exit_callback=self.proc_exit_cb, stdin=self.channel)
         self.channel.start_read2(self.on_channel_read)
         self.loop.run()
 
 
 if __name__ == '__main__':
-    import unittest
-    tests = unittest.TestSuite(common.suites)
-    unittest.TextTestRunner(verbosity=2).run(tests)
-
+    unittest2.main(verbosity=2)
