@@ -3,11 +3,12 @@ import os
 import signal
 import threading
 
-import common
+from common import unittest2, platform_skip
 import pyuv
 
 
-class SignalTest(common.UVTestCase):
+@platform_skip(["win32"])
+class SignalTest(unittest2.TestCase):
 
     def setUp(self):
         self.async_cb_called = 0
@@ -42,7 +43,5 @@ class SignalTest(common.UVTestCase):
 
 
 if __name__ == '__main__':
-    import unittest
-    tests = unittest.TestSuite(common.suites)
-    unittest.TextTestRunner(verbosity=2).run(tests)
+    unittest2.main(verbosity=2)
 
