@@ -1,13 +1,14 @@
 
-import os
+import sys
 
+from common import unittest2
 import common
 import pyuv
 
 
 TEST_PORT = 1234
 
-class TCPErrorTest(common.UVTestCase):
+class TCPErrorTest(unittest2.TestCase):
 
     def on_client_connect_error(self, client, error):
         self.assertNotEqual(error, None)
@@ -20,7 +21,7 @@ class TCPErrorTest(common.UVTestCase):
         loop.run()
 
 
-class TCPTest(common.UVTestCase):
+class TCPTest(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
@@ -34,7 +35,7 @@ class TCPTest(common.UVTestCase):
         server.accept(client)
         self.client_connections.append(client)
         client.start_read(self.on_client_connection_read)
-        client.write("PING"+os.linesep)
+        client.write(b"PING"+common.linesep)
 
     def on_client_connection_read(self, client, data, error):
         if data is None:
@@ -50,7 +51,7 @@ class TCPTest(common.UVTestCase):
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
         data = data.strip()
-        self.assertEquals(data, "PING")
+        self.assertEquals(data, b"PING")
         client.close()
 
     def test_tcp1(self):
@@ -62,7 +63,7 @@ class TCPTest(common.UVTestCase):
         self.loop.run()
 
 
-class TCPTestNull(common.UVTestCase):
+class TCPTestNull(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
@@ -76,7 +77,7 @@ class TCPTestNull(common.UVTestCase):
         server.accept(client)
         self.client_connections.append(client)
         client.start_read(self.on_client_connection_read)
-        client.write("PIN\x00G"+os.linesep)
+        client.write(b"PIN\x00G"+common.linesep)
 
     def on_client_connection_read(self, client, data, error):
         if data is None:
@@ -92,7 +93,7 @@ class TCPTestNull(common.UVTestCase):
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
         data = data.strip()
-        self.assertEquals(data, "PIN\x00G")
+        self.assertEquals(data, b"PIN\x00G")
         client.close()
 
     def test_tcp_null(self):
@@ -104,7 +105,7 @@ class TCPTestNull(common.UVTestCase):
         self.loop.run()
 
 
-class TCPTestList(common.UVTestCase):
+class TCPTestList(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
@@ -117,7 +118,7 @@ class TCPTestList(common.UVTestCase):
         server.accept(client)
         self.client_connections.append(client)
         client.start_read(self.on_client_connection_read)
-        client.write(["PING1", "PING2", "PING3", "PING4", "PING5", "PING6", os.linesep])
+        client.write([b"PING1", b"PING2", b"PING3", b"PING4", b"PING5", b"PING6", common.linesep])
 
     def on_client_connection_read(self, client, data, error):
         if data is None:
@@ -133,7 +134,7 @@ class TCPTestList(common.UVTestCase):
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
         data = data.strip()
-        self.assertEquals(data, "PING1PING2PING3PING4PING5PING6")
+        self.assertEquals(data, b"PING1PING2PING3PING4PING5PING6")
         client.close()
 
     def test_tcp_list(self):
@@ -145,7 +146,7 @@ class TCPTestList(common.UVTestCase):
         self.loop.run()
 
 
-class TCPTestListNull(common.UVTestCase):
+class TCPTestListNull(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
@@ -158,7 +159,7 @@ class TCPTestListNull(common.UVTestCase):
         server.accept(client)
         self.client_connections.append(client)
         client.start_read(self.on_client_connection_read)
-        client.write(["PING1", "PING2", "PING3", "PING4", "PING5", "PING\x00\xFF6", os.linesep])
+        client.write([b"PING1", b"PING2", b"PING3", b"PING4", b"PING5", b"PING\x00\xFF6", common.linesep])
 
     def on_client_connection_read(self, client, data, error):
         if data is None:
@@ -174,7 +175,7 @@ class TCPTestListNull(common.UVTestCase):
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
         data = data.strip()
-        self.assertEquals(data, "PING1PING2PING3PING4PING5PING\x00\xFF6")
+        self.assertEquals(data, b"PING1PING2PING3PING4PING5PING\x00\xFF6")
         client.close()
 
     def test_tcp_list_null(self):
@@ -186,7 +187,7 @@ class TCPTestListNull(common.UVTestCase):
         self.loop.run()
 
 
-class TCPTestInvalidData(common.UVTestCase):
+class TCPTestInvalidData(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
@@ -200,7 +201,12 @@ class TCPTestInvalidData(common.UVTestCase):
         self.client_connections.append(client)
         client.start_read(self.on_client_connection_read)
 
-        self.assertRaises(TypeError, client.write, u'Unicode Data')
+        if sys.version_info >= (3, 0):
+            data = 'Unicode'
+        else:
+            data = unicode('Unicode')
+
+        self.assertRaises(TypeError, client.write, data)
         self.assertRaises(TypeError, client.write, 1)
 
         client.close()
@@ -231,7 +237,7 @@ class TCPTestInvalidData(common.UVTestCase):
         self.loop.run()
 
 
-class TCPShutdownTest(common.UVTestCase):
+class TCPShutdownTest(unittest2.TestCase):
 
     def setUp(self):
         self.loop = pyuv.Loop.default_loop()
@@ -244,7 +250,7 @@ class TCPShutdownTest(common.UVTestCase):
         server.accept(client)
         self.client_connections.append(client)
         client.start_read(self.on_client_connection_read)
-        client.write("PING"+os.linesep)
+        client.write(b"PING"+common.linesep)
 
     def on_client_connection_read(self, client, data, error):
         if data is None:
@@ -267,7 +273,7 @@ class TCPShutdownTest(common.UVTestCase):
     def on_client_read(self, client, data, error):
         self.assertNotEqual(data, None)
         data = data.strip()
-        self.assertEquals(data, "PING")
+        self.assertEquals(data, b"PING")
         client.shutdown(self.on_client_shutdown)
 
     def test_tcp_shutdown(self):
@@ -283,7 +289,7 @@ class TCPShutdownTest(common.UVTestCase):
         self.assertEqual(self.close_cb_called, 3)
 
 
-class TCPFlagsTest(common.UVTestCase):
+class TCPFlagsTest(unittest2.TestCase):
 
     def test_tcp_flags(self):
         loop = pyuv.Loop.default_loop()
@@ -297,7 +303,5 @@ class TCPFlagsTest(common.UVTestCase):
 
 
 if __name__ == '__main__':
-    import unittest
-    tests = unittest.TestSuite(common.suites)
-    unittest.TextTestRunner(verbosity=2).run(tests)
+    unittest2.main(verbosity=2)
 
